from distutils.core import setup

version = '0.0.1'

setup(
    name='pygman',
    packages=['pygman'],
    version=version,
    description='For personal use',
    author='pygman',
    author_email='pygman@aliyun.com',
    url='https://github.com/pygman/pygman',
    download_url='https://github.com/pygman/pygman/archive/%s.tar.gz' % version,
    keywords=['testing', 'logging', 'example', 'self'],
    classifiers=[],
)
